@@ -2,7 +2,7 @@
 
 (c) 2007-2012 Matt Hilton
 
-(c) 2013-2014 Matt Hilton & Steven Boada
+(c) 2013-2016 Matt Hilton & Steven Boada
 
 U{http://astlib.sourceforge.net}
 
@@ -12,6 +12,7 @@ import sys
 import math
 import numpy
 from PyWCSTools import wcscon
+#import IPython
 
 #-----------------------------------------------------------------------------
 def hms2decimal(RAString, delimiter):
@@ -232,8 +233,7 @@ def decimal2dms(decDeg, delimiter):
 #-----------------------------------------------------------------------------
 def calcAngSepDeg(RADeg1, decDeg1, RADeg2, decDeg2):
     """Calculates the angular separation of two positions on the sky (specified
-    in decimal degrees) in decimal degrees, assuming a tangent plane projection
-    (so separation has to be <90 deg). Note that RADeg2, decDeg2 can be numpy
+    in decimal degrees) in decimal degrees. Note that RADeg2, decDeg2 can be numpy
     arrays.
 
     @type RADeg1: float
@@ -248,21 +248,32 @@ def calcAngSepDeg(RADeg1, decDeg1, RADeg2, decDeg2):
     @return: angular separation in decimal degrees
 
     """
-    cRA = numpy.radians(RADeg1)
-    cDec = numpy.radians(decDeg1)
-
-    gRA = numpy.radians(RADeg2)
-    gDec = numpy.radians(decDeg2)
-
-    dRA = cRA-gRA
-    dDec = gDec-cDec
-    cosC = ((numpy.sin(gDec)*numpy.sin(cDec)) +
-        (numpy.cos(gDec)*numpy.cos(cDec) * numpy.cos(gRA-cRA)))
-    x = (numpy.cos(cDec)*numpy.sin(gRA-cRA))/cosC
-    y = (((numpy.cos(gDec)*numpy.sin(cDec)) - (numpy.sin(gDec) *
-        numpy.cos(cDec)*numpy.cos(gRA-cRA)))/cosC)
-    r = numpy.degrees(numpy.sqrt(x*x+y*y))
-
+    
+    a=numpy.sin(numpy.radians(decDeg1))*numpy.sin(numpy.radians(decDeg2))+numpy.cos(numpy.radians(decDeg1))*numpy.cos(numpy.radians(decDeg2))*numpy.cos(numpy.radians(RADeg1-RADeg2))
+    mask=numpy.greater(a, 1.0)
+    if mask.sum() > 0:
+        a[mask]=1.0
+    r=numpy.degrees(numpy.arccos(a))
+            
+    # Above gives nan when RADeg1, decDeg1 == RADeg1, decDeg2
+    indexList=numpy.where(numpy.isnan(r) == True)[0]
+    tolerance=1e-6
+    if len(indexList) > 0:
+        for index in indexList:
+            if type(r) == numpy.ndarray:
+                if type(RADeg2) == numpy.ndarray:
+                    if abs(RADeg1 - RADeg2[index]) < tolerance and abs(decDeg1 -decDeg2[index]) < tolerance:
+                        r[index]=0.0
+                    else:
+                        raise Exception("astCoords: calcAngSepDeg - encountered nan not due to equal RADeg, decDeg coords")
+                elif type(RADeg1) == numpy.ndarray:
+                    if abs(RADeg2 - RADeg1[index]) < tolerance and abs(decDeg2 -decDeg1[index]) < tolerance: 
+                        r[index]=0.0
+                    else:
+                        raise Exception("astCoords: calcAngSepDeg - encountered nan not due to equal RADeg, decDeg coords")
+            else:
+                r=0.0
+        
     return r
 
 #-----------------------------------------------------------------------------
@@ -371,10 +382,11 @@ def calcRADecSearchBox(RADeg, decDeg, radiusSkyDeg):
     results = []
     for f, c, sign in zip(funcCalls, coords, signs):
         # Initial guess range
-        maxGuess = sign*targetHalfSizeSkyDeg*10.0
-        minGuess = sign*targetHalfSizeSkyDeg/10.0
-        guessStep = (maxGuess-minGuess)/10.0
-        guesses = numpy.arange(minGuess+c, maxGuess+c, guessStep)
+        maxGuess = sign*targetHalfSizeSkyDeg*20.0
+        minGuess = sign*targetHalfSizeSkyDeg/20.0
+        #guessStep = (maxGuess-minGuess)/10.0
+        guesses = numpy.linspace(minGuess+c, maxGuess+c, 1000)
+        converged=False
         for i in range(50):
             minSizeDiff = 1e6
             bestGuess = None
@@ -384,13 +396,26 @@ def calcRADecSearchBox(RADeg, decDeg, radiusSkyDeg):
                     minSizeDiff = sizeDiff
                     bestGuess = guess
             if minSizeDiff < tolerance:
+                converged=True
                 break
             else:
+                #print sizeDiff, bestGuess, bestGuess-minGuess, bestGuess-maxGuess
+                if bestGuess == None:
+                    raise Exception("bestGuess is None")
                 guessRange = abs((maxGuess-minGuess))
                 maxGuess = bestGuess+guessRange/4.0
                 minGuess = bestGuess-guessRange/4.0
-                guessStep = (maxGuess-minGuess)/10.0
-                guesses = numpy.arange(minGuess, maxGuess, guessStep)
+                # Stop us from searching the wrong side of the coordinate
+                if sign == 1:
+                    if minGuess < c:
+                        minGuess=c+tolerance
+                if sign == -1:
+                    if maxGuess > c:
+                        maxGuess=c-tolerance
+                #guessStep = (maxGuess-minGuess)/20.0
+                guesses = numpy.linspace(minGuess, maxGuess, 1000)
+        if converged == False:
+            raise Exception("calcRADecSearchBox failed to converge")
         results.append(bestGuess)
 
     RAMax = results[0]
@@ -398,5 +423,9 @@ def calcRADecSearchBox(RADeg, decDeg, radiusSkyDeg):
     decMax = results[2]
     decMin = results[3]
 
+    # Sanity check
+    if (RAMax-RAMin)+(2*tolerance) < 2*targetHalfSizeSkyDeg:
+        raise Exception("calcRADecSearchBox failed sanity check")
+
     return [RAMin, RAMax, decMin, decMax]
 
